*diskmap*
=========

.. image:: https://img.shields.io/pypi/v/diskmap
   :target: https://pypi.python.org/pypi/diskmap

.. image:: https://img.shields.io/pypi/pyversions/diskmap
   :target: https://pypi.python.org/pypi/diskmap

.. image:: https://github.com/tomasstolker/diskmap/workflows/CI/badge.svg?branch=main
   :target: https://github.com/tomasstolker/diskmap/actions

.. image:: https://img.shields.io/readthedocs/diskmap
   :target: http://diskmap.readthedocs.io

.. image:: https://codecov.io/gh/tomasstolker/diskmap/branch/main/graph/badge.svg?token=UZ7OS5WR9C
   :target: https://codecov.io/gh/tomasstolker/diskmap

.. image:: https://img.shields.io/codefactor/grade/github/tomasstolker/diskmap
   :target: https://www.codefactor.io/repository/github/tomasstolker/diskmap

.. image:: https://img.shields.io/github/license/tomasstolker/diskmap
   :target: https://github.com/tomasstolker/diskmap/blob/main/LICENSE

.. image:: https://mybinder.org/badge_logo.svg
   :target: https://mybinder.org/v2/gh/tomasstolker/diskmap/HEAD

*diskmap* is a tool for scattered light mapping of protoplanetary disks. The disk surface is parameterized with a power law profile or read from an input file. The projected radius and scattering angle are then calculated at each pixel. From this, a 3D deprojected image and a stellar irradiation corrected image are computed. Also a polarized scattering phase function is extracted and an total intensity phase function is estimated.

Documentation
-------------

Documentation can be found at `http://diskmap.readthedocs.io <http://diskmap.readthedocs.io>`_. There is a `notebook tutorial <https://diskmap.readthedocs.io/en/latest/tutorial.html>`_ that demonstrates the usage. It can also be executed in the interactive environment of `Binder <https://mybinder.org/v2/gh/tomasstolker/diskmap/HEAD>`_.

Attribution
-----------

Please cite `Stolker et al. (2016b) <https://ui.adsabs.harvard.edu/abs/2016A%26A...596A..70S>`_ whenever results from *diskmap* are used in a publication (see `arXiv <https://arxiv.org/abs/1609.09505>`_, `ADS <https://ui.adsabs.harvard.edu/abs/2016A%26A...596A..70S>`_, `BibTeX <https://ui.adsabs.harvard.edu/abs/2016A%26A...596A..70S/exportcitation>`_).

Contributing
------------

Contributions are welcome so please consider `forking <https://help.github.com/en/articles/fork-a-repo>`_ the repository and creating a `pull request <https://github.com/tomasstolker/diskmap/pulls>`_. Bug reports and feature requests can be provided by creating an `issue <https://github.com/tomasstolker/diskmap/issues>`_ on the Github page.

License
-------

Copyright 2020-2022 Tomas Stolker

*diskmap* is distributed under the MIT License. See the LICENSE file for the terms and conditions.
